@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 
 import os
 import sys
@@ -51,6 +50,7 @@ html_context = {
 
 html_static_path = [
     "extra.css",
+    "images/logo-small.svg",
 ]
 
 suppress_warnings = ["image.nonlocal_uri"]
